Regression function for Linear's model
.MicrobialGrowth.linear(
x,
y,
clip = c(-Inf, Inf),
start = list(),
lower = list(),
upper = list(),
nls.args = list(),
callbackError = NULL
)a MicrobialGrowth-object composed of
the matched call with several components.
coefficients obtained by regression.
data used for regression, once the y values are clipped
a list of functions such as formula to retrieve the function of the model with the coefficients obtained by regression, confint to retrieve the confidence intervals, etc.
a boolean indicating whether the regression was successful or not.
contains the error message if the regression fails, NULL otherwise.
the nls object returned by the nls function.
index series or time series.
values or list of values to regress (should not be logged).
a pair of values indicating in which interval to clip the data y. When clip is missing, default values are used.
a named list of starting estimates. When start is missing, default values are used.
a named list of lower bounds. When lower is missing, default values are used.
a named list of upper bounds. When upper is missing, default values are used.
additional parameters to use when calling nls.
function to call on error during regression.
The default values for clip, start, lower and upper are calculated based on the given data. These default values can be known through the call member of the returned value.
The nls.args argument is a list that can contain any nls function argument except formula, algorithm, start, lower and upper which are already fixed (via a homonymous or hard-coded argument).
For the callbackError argument, prefer the stop function to block or warning to not be blocking.
MicrobialGrowth, .linear.formula