Check the arguments passed to the regression function.
Tests are generic for all models. For example, the same length for x and y, the type of the
different arguments, the values inserted in start, lower and upper, etc. are tested
.checkMicrobialGrowthArgs(
x,
y,
clip,
start,
lower,
upper,
nls.args,
callbackError
)the modified clip value and raises an error if something is wrong.
index series or time series.
values or list of values to regress (should not be logged).
a pair of values indicating in which interval to clip the data y. When clip is missing, default values are used.
a named list of starting estimates. When start is missing, default values are used.
a named list of lower bounds. When lower is missing, default values are used.
a named list of upper bounds. When upper is missing, default values are used.
additional parameters to use when calling nls.
function to call on error during regression.
During the check, the clip value is also updated. If the lower bound of clip is -Inf (default value), then this value is replaced by the smallest value greater than zero found in y.