Check the arguments passed to the create function.
Tests are generic for all models. For example, the type and value xlim,
the values of N0, Nmax, etc. are tested.
.checkMicrobialGrowthCreateArgs(N0, Nmax, mu, lambda, xlim, n)raise an error if something is wrong.
initial population.
final/maximum population.
growth rate.
latency time.
range of values to simulate x and y (and hence plotting, etc.)
number of points to simulate in the interval xlim.