Learn R Programming

MicrobialGrowth (version 1.0.0)

.new.linear.core: Linear object

Description

A MicrobialGrowth object specialized for the linear model. Most of the methods are pre-implemented (some of these can be overwritten for a specific regression/create function). Must be completed for data, isValid (regression successful), etc.

Usage

.new.linear.core(...)

Value

a linear object skeleton.

Arguments

...

further arguments passed to or from other methods.

Details

the three dots ... are passed to the .new.MicrobialGrowth.core function.

Examples

Run this code
# First, create the skeleton.
model.object = .new.linear.core()

# Then complete with data, functions, etc.
model.object$data$x = c(1,2,3)
model.object$data$y = c(1,2,3)
model.object$coefficients = list(N0 = 0, Nmax=0, mu=0, lambda=0)

# You can print, plot, etc., with the generic functions of MicrobialGrowth.
print(model.object)
##MicrobialGrowth, model specialized.model:
##    N0   Nmax     mu lambda
##     0      0      0      0
plot(model.object)

# Don't forget to change `isValid` to TRUE to confirm the success of the regression.
model.object$isValid = TRUE # Not a good idea here, since we have no `reg` value.

Run the code above in your browser using DataLab