.rosso.formula(N0, Nmax, mu, lambda, base = exp(1))
Value
a function taking as input x (the time) and outputting the value of the Rosso equation.
Arguments
N0
initial population.
Nmax
final/maximum population.
mu
growth rate.
lambda
latency time.
base
the logarithm base used for plot y-scaling. By default, the natural logarithm is used. Set NULL to not scale.
Details
The output result is by default in the form ln(N_t/N0) (with N_t the population at time t).
The base used can be modified by specifying the desired base in the base argument.
For example, specifying base=10 corresponds to output in the form log_{10}(N_t/N0).
It is possible to specify base = NULL to retrieve the normal N_t output.